Learn R Programming

ctmva (version 1.6.0)

cov.ct: Continuous-time covariance or cross-covariance matrix

Description

Computes the covariance matrix of a continuous-time multivariate data set represented as an fd object; or the cross-covariance matrix of two such data sets.

Usage

cov.ct(fdobj1, fdobj2 = fdobj1, common_trend = FALSE)

Value

A matrix of (cross-) covariances

Arguments

fdobj1

continuous-time multivariate data set of class "fd"

fdobj2

an optional second data set

common_trend

logical: centering with respect to the mean function if TRUE, without centering if FALSE (the default)

Author

Biplab Paul <paul.biplab497@gmail.com> and Philip Tzvi Reiss <reiss@stat.haifa.ac.il>

See Also

cor.ct

Examples

Run this code

# see example for cor.ct, which works similarly

Run the code above in your browser using DataLab