A continuous-time version of k-means clustering in which each cluster is a time segments or set of time segments.
kmeans.ct(
fdobj,
k,
common_trend = FALSE,
init.pts = NULL,
tol = 0.001,
max.iter = 100
)Object of class "kmeans.ct", a list consisting of
the supplied fdobj
means of the k clusters
transition points between segments
cluster memberships in the segments defined by the transitions
length of each cluster, i.e. sum of lengths of subintervals making up each cluster
total integrated sum of distances from the overall mean, analogous to totss from kmeans
within-cluster integrated sum of distances, i.e. integrated sum of distances from each cluster mean
total within-cluster integrated sum of distances, i.e. sum(withinisd)
between-cluster integrated sum of distances, i.e. totisd-tot.withinss
continuous-time multivariate data set of class "fd"
number of clusters
logical: Should the curves be centered with respect to the mean function?
Defaults to FALSE.
a set of k time points. The observations at these time points serve as initial values for the k means. Randomly generated if not supplied.
convergence tolerance for the k means
maximum number of iterations
Biplab Paul <paul.biplab497@gmail.com> and Philip Tzvi Reiss <reiss@stat.haifa.ac.il>
kmeans, plot.kmeans.ct, silhouette.ct