Learn R Programming

ctmva (version 1.6.0)

silhouette.ct: Silhouettes for continuous-time k-means clustering

Description

Computes the silhouette index, at a grid of time points, for a continuous-time k-means clustering object produced by kmeans.ct.

Usage

silhouette.ct(kmobj, ngrid = 5000)

Value

Object of class "silhouette.ct", a list consisting of

grid

grid of ngrid points spanning the time range

value

silhouette index at each point along the grid

transitions

transition points between segments

cluster

cluster memberships in the segments defined by the transitions

mean

mean silhouette index

Arguments

kmobj

continuous-time k-means clustering from kmeans.ct

ngrid

number of equally spaced grid points at which to compute the silhouette index

Author

Philip Tzvi Reiss <reiss@stat.haifa.ac.il>

See Also

kmeans.ct, which includes an example; plot.silhouette.ct