powered by
Computes the covariance matrix of a continuous-time multivariate data set represented as an fd object; or the cross-covariance matrix of two such data sets.
fd
cov.ct(fdobj1, fdobj2 = fdobj1, common_trend = FALSE)
A matrix of (cross-) covariances
continuous-time multivariate data set of class "fd"
"fd"
an optional second data set
logical: centering with respect to the mean function if TRUE, without centering if FALSE (the default)
TRUE
FALSE
Biplab Paul <paul.biplab497@gmail.com> and Philip Tzvi Reiss <reiss@stat.haifa.ac.il>
cor.ct
# see example for cor.ct, which works similarly
Run the code above in your browser using DataLab