Computes the silhouette index, at a grid of time points, for a continuous-time
k-means clustering object produced by kmeans.ct.
silhouette.ct(kmobj, ngrid = 5000)Object of class "silhouette.ct", a list consisting of
grid of ngrid points spanning the time range
silhouette index at each point along the grid
transition points between segments
cluster memberships in the segments defined by the transitions
mean silhouette index
continuous-time k-means clustering from kmeans.ct
number of equally spaced grid points at which to compute the silhouette index
Philip Tzvi Reiss <reiss@stat.haifa.ac.il>
kmeans.ct, which includes an example; plot.silhouette.ct